@@ -22,10 +22,10 @@ else:
 
 __all__ = (
     "DataPointTypeDef",
-    "ForecastTypeDef",
     "QueryForecastRequestRequestTypeDef",
-    "QueryForecastResponseTypeDef",
     "ResponseMetadataTypeDef",
+    "ForecastTypeDef",
+    "QueryForecastResponseTypeDef",
 )
 
 DataPointTypeDef = TypedDict(
@@ -37,14 +37,6 @@ DataPointTypeDef = TypedDict(
     total=False,
 )
 
-ForecastTypeDef = TypedDict(
-    "ForecastTypeDef",
-    {
-        "Predictions": Dict[str, List["DataPointTypeDef"]],
-    },
-    total=False,
-)
-
 _RequiredQueryForecastRequestRequestTypeDef = TypedDict(
     "_RequiredQueryForecastRequestRequestTypeDef",
     {
@@ -69,14 +61,6 @@ class QueryForecastRequestRequestTypeDef(
     pass
 
 
-QueryForecastResponseTypeDef = TypedDict(
-    "QueryForecastResponseTypeDef",
-    {
-        "Forecast": "ForecastTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
@@ -87,3 +71,19 @@ ResponseMetadataTypeDef = TypedDict(
         "RetryAttempts": int,
     },
 )
+
+ForecastTypeDef = TypedDict(
+    "ForecastTypeDef",
+    {
+        "Predictions": Dict[str, List[DataPointTypeDef]],
+    },
+    total=False,
+)
+
+QueryForecastResponseTypeDef = TypedDict(
+    "QueryForecastResponseTypeDef",
+    {
+        "Forecast": ForecastTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
